@@ -6,6 +6,7 @@ package MARC::SubjectMap::Handler;
 use strict;
 use warnings;
 use base qw( XML::SAX::Base );
+use Encode;
 
 use MARC::SubjectMap;
 use MARC::SubjectMap::Rule;
@@ -110,6 +111,7 @@ sub characters {
     my ($self,$data) = @_;
     my $text = $data->{Data};
     $text =~ s/[\r\n]//g; # strip newlines
+    Encode::_utf8_off( $text );
     $self->{text} .= $text;
 }
 
