@@ -7,13 +7,20 @@ use strict;
 use warnings;
 
 use base qw( Exporter );
-our @EXPORT_OK = qw( element esc startTag endTag );
+our @EXPORT_OK = qw( element emptyElement esc startTag endTag comment );
 
 sub element {
     my ($tag,$content,@attrs) = @_;
     return startTag($tag,@attrs).esc($content).endTag($tag);
 }
 
+sub emptyElement {
+    my ($tag,@attrs) = @_;
+    my $xml = startTag( $tag,@attrs); 
+    $xml =~ s{>$}{ />};
+    return $xml;
+}
+
 sub startTag {
     my ($tag,@attrs) = @_;
     my $xml = "<$tag";
@@ -41,6 +48,11 @@ sub esc {
     return $str;
 }
 
+sub comment {
+    my $str = shift;
+    return qq(<!-- $str -->);
+}
+
 1;
 
 
